@@ -56,7 +56,7 @@ class spectrum:
 		try:
 			return os.environ['SPECTRUM_PATH']
 		except KeyError:
-			return 'spectrum'
+			return '/usr/local/sbin/spectrum'
 
 	def get_jid( self ):
 		"""
